@@ -305,8 +305,8 @@ class RKXMLRequest(XMLRequest):
                         min_tarif_amount=(item.attrib['MinTarifAmount']),
                         max_tarif_amount=(item.attrib['MaxTarifAmount']),
                         availability_schedule=(item.attrib['AvailabilitySchedule']),
-                        dont_pack=(item.attrib['DontPack'])
-                    )
+                        dont_pack=(item.attrib['DontPack']), portion_weight=(item.attrib['PortionWeight']),
+                        portion_name=(item.attrib['PortionName']))
                     element.append(menu_items_dto)
         except Exception as error:
             raise ParseError(f"XML parse error - {str(error)}")
